@@ -1,7 +1,7 @@
 /*
  * wee-upgrade.c - save/restore session data of WeeChat core
  *
- * Copyright (C) 2003-2023 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -546,16 +546,7 @@ upgrade_weechat_read_buffer (struct t_infolist *infolist)
         }
     }
 
-    /* text search */
-    ptr_buffer->text_search = infolist_integer (infolist, "text_search");
-    ptr_buffer->text_search_exact = infolist_integer (infolist,
-                                                      "text_search_exact");
-    ptr_buffer->text_search_found = infolist_integer (infolist,
-                                                      "text_search_found");
-    if (ptr_buffer->text_search_input)
-        free (ptr_buffer->text_search_input);
-    str = infolist_string (infolist, "text_search_input");
-    ptr_buffer->text_search_input = (str) ? strdup (str) : NULL;
+    /* text search is disabled after upgrade */
 
     /* highlight options */
     gui_buffer_set_highlight_words (
@@ -645,13 +636,16 @@ upgrade_weechat_read_buffer_line (struct t_infolist *infolist)
     switch (upgrade_current_buffer->type)
     {
         case GUI_BUFFER_TYPE_FORMATTED:
-            new_line = gui_line_new (upgrade_current_buffer,
-                                     -1,
-                                     infolist_time (infolist, "date"),
-                                     infolist_time (infolist, "date_printed"),
-                                     infolist_string (infolist, "tags"),
-                                     infolist_string (infolist, "prefix"),
-                                     infolist_string (infolist, "message"));
+            new_line = gui_line_new (
+                upgrade_current_buffer,
+                -1,
+                infolist_time (infolist, "date"),
+                infolist_integer (infolist, "date_usec"),
+                infolist_time (infolist, "date_printed"),
+                infolist_integer (infolist, "date_usec_printed"),
+                infolist_string (infolist, "tags"),
+                infolist_string (infolist, "prefix"),
+                infolist_string (infolist, "message"));
             if (new_line)
             {
                 new_line->data->id = infolist_integer (infolist, "id");
@@ -663,13 +657,16 @@ upgrade_weechat_read_buffer_line (struct t_infolist *infolist)
             }
             break;
         case GUI_BUFFER_TYPE_FREE:
-            new_line = gui_line_new (upgrade_current_buffer,
-                                     infolist_integer (infolist, "y"),
-                                     infolist_time (infolist, "date"),
-                                     infolist_time (infolist, "date_printed"),
-                                     infolist_string (infolist, "tags"),
-                                     NULL,
-                                     infolist_string (infolist, "message"));
+            new_line = gui_line_new (
+                upgrade_current_buffer,
+                infolist_integer (infolist, "y"),
+                infolist_time (infolist, "date"),
+                infolist_integer (infolist, "date_usec"),
+                infolist_time (infolist, "date_printed"),
+                infolist_integer (infolist, "date_usec_printed"),
+                infolist_string (infolist, "tags"),
+                NULL,
+                infolist_string (infolist, "message"));
             if (new_line)
             {
                 new_line->data->id = infolist_integer (infolist, "id");
