@@ -1,7 +1,7 @@
 /*
  * irc-message.c - functions for IRC messages
  *
- * Copyright (C) 2003-2023 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -625,6 +625,7 @@ irc_message_parse_cap_multiline_value (struct t_irc_server *server,
     ptr_value = (const char *)weechat_hashtable_get (values, "max-bytes");
     if (ptr_value)
     {
+        error = NULL;
         number = strtol (ptr_value, &error, 10);
         if (error && !error[0])
             server->multiline_max_bytes = number;
@@ -633,6 +634,7 @@ irc_message_parse_cap_multiline_value (struct t_irc_server *server,
     ptr_value = (const char *)weechat_hashtable_get (values, "max-lines");
     if (ptr_value)
     {
+        error = NULL;
         number = strtol (ptr_value, &error, 10);
         if (error && !error[0])
             server->multiline_max_lines = number;
@@ -1053,9 +1055,6 @@ irc_message_split_string (struct t_irc_message_split_context *context,
     if (suffix)
         max_length -= strlen (suffix);
 
-    if (max_length < 2)
-        return 0;
-
     /* debug message */
     if (weechat_irc_plugin->debug >= 2)
     {
@@ -1067,17 +1066,23 @@ irc_message_split_string (struct t_irc_message_split_context *context,
                         max_length);
     }
 
-    if (!arguments || !arguments[0])
+    if ((max_length < 2) || !arguments || !arguments[0])
     {
-        snprintf (message, sizeof (message), "%s%s%s %s%s%s%s",
+        /*
+         * max length is not known (server probably sent values that are not
+         * consistent), or no arguments => in this case, we just return message
+         * as-is (no split)
+         */
+        snprintf (message, sizeof (message), "%s%s%s %s%s%s%s%s",
                   (host) ? host : "",
                   (host) ? " " : "",
                   command,
                   (target) ? target : "",
                   (target && target[0]) ? " " : "",
                   (prefix) ? prefix : "",
+                  (arguments) ? arguments : "",
                   (suffix) ? suffix : "");
-        irc_message_split_add (context, tags, message, "");
+        irc_message_split_add (context, tags, message, (arguments) ? arguments : "");
         (context->number)++;
         return 1;
     }
