@@ -229,13 +229,13 @@ TEST(CoreUtil, Strftimeval)
 
     /* invalid microseconds digits (must be 1-6) */
     strcpy (str_time, "test");
-    LONGS_EQUAL(23, util_strftimeval (str_time, sizeof (str_time),
+    LONGS_EQUAL(20, util_strftimeval (str_time, sizeof (str_time),
                                       "%Y-%m-%d %H:%M:%S.%.0", &tv));
-    STRCMP_EQUAL("2023-12-25 10:29:09.%.0", str_time);
+    STRCMP_EQUAL("2023-12-25 10:29:09.", str_time);
     strcpy (str_time, "test");
-    LONGS_EQUAL(23, util_strftimeval (str_time, sizeof (str_time),
+    LONGS_EQUAL(20, util_strftimeval (str_time, sizeof (str_time),
                                       "%Y-%m-%d %H:%M:%S.%.7", &tv));
-    STRCMP_EQUAL("2023-12-25 10:29:09.%.7", str_time);
+    STRCMP_EQUAL("2023-12-25 10:29:09.", str_time);
 }
 
 /*
